@@ -392,7 +392,7 @@ BamRecord::~BamRecord() = default;
 
 Data::Position BamRecord::AlignedEnd() const
 {
-    if (alignedEnd_ == Data::UnmappedPosition) {
+    if (alignedEnd_ == Data::UNMAPPED_POSITION) {
         CalculateAlignedPositions();
     }
     return alignedEnd_;
@@ -400,7 +400,7 @@ Data::Position BamRecord::AlignedEnd() const
 
 Data::Position BamRecord::AlignedStart() const
 {
-    if (alignedStart_ == Data::UnmappedPosition) {
+    if (alignedStart_ == Data::UNMAPPED_POSITION) {
         CalculateAlignedPositions();
     }
     return alignedStart_;
@@ -508,7 +508,7 @@ void BamRecord::CalculateAlignedPositions() const
     const Data::Position qStart = isCcsOrTranscript ? 0 : QueryStart();
     const Data::Position qEnd = isCcsOrTranscript ? seqLength : QueryEnd();
 
-    if (qStart == Data::UnmappedPosition || qEnd == Data::UnmappedPosition) {
+    if (qStart == Data::UNMAPPED_POSITION || qEnd == Data::UNMAPPED_POSITION) {
         return;
     }
 
@@ -1667,8 +1667,8 @@ BamRecord& BamRecord::Map(const int32_t referenceId, const Data::Position refSta
     }
 
     // reset any cached aligned start/end
-    alignedStart_ = Data::UnmappedPosition;
-    alignedEnd_ = Data::UnmappedPosition;
+    alignedStart_ = Data::UNMAPPED_POSITION;
+    alignedEnd_ = Data::UNMAPPED_POSITION;
 
     return *this;
 }
@@ -1758,10 +1758,11 @@ std::vector<int32_t> BamRecord::SplitBasemods::SplitBasemodsString(const std::st
     assert(boost::algorithm::starts_with(str, "C+m"));
     assert(boost::algorithm::ends_with(str, ";"));
 
-    const char* strView = str.c_str() + 3;  // skip the "C+m" prefix
-    const int32_t strLen = str.size() - 3;
+    const int32_t skipPrefix = 3 + boost::algorithm::starts_with(str, "C+m?");
+    const char* strView = str.c_str() + skipPrefix;  // skip the "C+m?" or "C+m" prefix
+    const int32_t strLen = str.size() - skipPrefix;
 
-    // convert "C+m,3,1,4;" to std::vector{3, 1, 4}
+    // convert "C+m?,3,1,4;" to std::vector{3, 1, 4}
     std::vector<int32_t> result;
     int32_t currentNumber = 0;
     assert((strView[0] == ',') ||
@@ -1786,7 +1787,7 @@ std::vector<int32_t> BamRecord::SplitBasemods::SplitBasemodsString(const std::st
 std::string BamRecord::SplitBasemods::SeparatingCToString(const std::vector<int32_t>& vec)
 {
     std::ostringstream newBasemodsString;
-    newBasemodsString << "C+m";
+    newBasemodsString << "C+m?";
     for (const auto val : vec) {
         newBasemodsString << ',' << val;
     }
@@ -2328,11 +2329,11 @@ int32_t BamRecord::ReadGroupNumericId() const { return ReadGroupInfo::IdToInt(Re
 Data::Position BamRecord::ReferenceEnd() const
 {
     if (!impl_.IsMapped()) {
-        return Data::UnmappedPosition;
+        return Data::UNMAPPED_POSITION;
     }
     const auto& htsData = BamRecordMemory::GetRawData(impl_);
     if (!htsData) {
-        return Data::UnmappedPosition;
+        return Data::UNMAPPED_POSITION;
     }
     return bam_endpos(htsData.get());
 }
@@ -2389,14 +2390,14 @@ BamRecord& BamRecord::ReversePulseWidth(const Data::Frames& frames, const Data::
 
 void BamRecord::ResetCachedPositions() const
 {
-    alignedEnd_ = Data::UnmappedPosition;
-    alignedStart_ = Data::UnmappedPosition;
+    alignedEnd_ = Data::UNMAPPED_POSITION;
+    alignedStart_ = Data::UNMAPPED_POSITION;
 }
 
 void BamRecord::ResetCachedPositions()
 {
-    alignedEnd_ = Data::UnmappedPosition;
-    alignedStart_ = Data::UnmappedPosition;
+    alignedEnd_ = Data::UNMAPPED_POSITION;
+    alignedStart_ = Data::UNMAPPED_POSITION;
 }
 
 VirtualRegionType BamRecord::ScrapRegionType() const
@@ -2469,8 +2470,8 @@ BamRecord& BamRecord::StartFrame(const std::vector<uint32_t>& startFrame)
     return *this;
 }
 
-QualityValues BamRecord::SubstitutionQV(Data::Orientation orientation, bool aligned,
-                                        bool exciseSoftClips) const
+Data::QualityValues BamRecord::SubstitutionQV(Data::Orientation orientation, bool aligned,
+                                              bool exciseSoftClips) const
 {
     return FetchQualities(BamRecordTag::SUBSTITUTION_QV, orientation, aligned, exciseSoftClips);
 }
