@@ -14,9 +14,9 @@
 using BamReader = PacBio::BAM::BamReader;
 using BamRecord = PacBio::BAM::BamRecord;
 using BamWriter = PacBio::BAM::BamWriter;
-using Cigar = PacBio::BAM::Cigar;
-using CigarOp = PacBio::BAM::CigarOperation;
-using PacBio::BAM::CigarOperationType;
+using Cigar = PacBio::Data::Cigar;
+using CigarOp = PacBio::Data::CigarOperation;
+using PacBio::Data::CigarOperationType;
 using Tag = PacBio::BAM::Tag;
 
 namespace LongCigarTests {
@@ -40,9 +40,9 @@ bool DoesHtslibSupportLongCigar()
     // check against v1.7
     const int versionMajor = std::stoi(versionParts[0]);
     const int versionMinor = std::stoi(versionParts[1]);
-    static constexpr const int v17_major = 1;
-    static constexpr const int v17_minor = 7;
-    return std::tie(versionMajor, versionMinor) >= std::tie(v17_major, v17_minor);
+    constexpr int V17_MAJOR = 1;
+    constexpr int V17_MINOR = 7;
+    return std::tie(versionMajor, versionMinor) >= std::tie(V17_MAJOR, V17_MINOR);
 }
 
 const bool has_native_long_cigar_support = DoesHtslibSupportLongCigar();
