@@ -9,9 +9,10 @@
 #include <pbbam/BamFile.h>
 #include <pbbam/BamHeader.h>
 #include <pbbam/BamRecord.h>
-#include <pbbam/Cigar.h>
 #include <pbbam/ReadGroupInfo.h>
 
+#include <pbcopper/data/Cigar.h>
+
 #include "../src/ValidationErrors.h"
 
 using namespace PacBio;
@@ -33,7 +34,7 @@ static BamRecord makeValidMappedRecord()
     impl.ReferenceId(0);
     impl.SetMapped(true);
     impl.SetSequenceAndQualities("AATGAGGAGA");
-    impl.CigarData(Cigar{"10="});
+    impl.CigarData(Data::Cigar{"10="});
 
     TagCollection tags;
     tags["RG"] = std::string{"db972a04"};
@@ -311,6 +312,28 @@ TEST(BAM_Validator, success_on_valid_header)
     ASSERT_NO_THROW(Validator::Validate(validUnmappedHeader));
 }
 
+TEST(BAM_Validator, success_on_valid_revio_header)
+{
+    static const BamHeader validMappedHeader{
+        "@HD\tVN:1.5\tSO:coordinate\tpb:3.0.7\n"
+        "@SQ\tSN:ecoliK12_pbi_March2013_2955000_to_2980000\tLN:25000\tM5:"
+        "734d5f3b2859595f4bd87a2fe6b7389b\n"
+        "@RG\tID:db972a04\tPL:PACBIO\tDS:READTYPE=SUBREAD;Ipd:CodecV1=ip;PulseWidth:CodecV1=pw;"
+        "BINDINGKIT=101-717-300;SEQUENCINGKIT=101-644-500;BASECALLERVERSION=5.0.0;FRAMERATEHZ=100."
+        "000000"
+        "\tPU:m64004_190414_193017\tPM:REVIO\n"};
+
+    static const BamHeader validUnmappedHeader{
+        "@HD\tVN:1.5\tSO:unknown\tpb:3.0.7\n"
+        "@RG\tID:db972a04\tPL:PACBIO\tDS:READTYPE=SUBREAD;Ipd:CodecV1=ip;PulseWidth:CodecV1=pw;"
+        "BINDINGKIT=101-717-300;SEQUENCINGKIT=101-644-500;BASECALLERVERSION=5.0.0;FRAMERATEHZ=100."
+        "000000\t"
+        "PU:m64004_190414_193017\tPM:REVIO\n"};
+
+    ASSERT_NO_THROW(Validator::Validate(validMappedHeader));
+    ASSERT_NO_THROW(Validator::Validate(validUnmappedHeader));
+}
+
 TEST(BAM_Validator, reports_invalid_header_data)
 {
     static const BamHeader validMappedHeader{
@@ -435,14 +458,14 @@ TEST(BAM_Validator, reports_invalid_tag_lengths)
         EXPECT_FALSE(Validator::IsValid(record));
     }
 
-    CheckInvalidTagLength("dq", QualityValues("@@").Fastq());  // DeletionQV
-    CheckInvalidTagLength("iq", QualityValues("@@").Fastq());  // InsertionQV
-    CheckInvalidTagLength("mq", QualityValues("@@").Fastq());  // MergeQV
-    CheckInvalidTagLength("sq", QualityValues("@@").Fastq());  // SubstitutionQV
-    CheckInvalidTagLength("dt", std::string("AA"));            // DeletionTag
-    CheckInvalidTagLength("st", std::string("AA"));            // SubstitutionTag
+    CheckInvalidTagLength("dq", Data::QualityValues("@@").Fastq());  // DeletionQV
+    CheckInvalidTagLength("iq", Data::QualityValues("@@").Fastq());  // InsertionQV
+    CheckInvalidTagLength("mq", Data::QualityValues("@@").Fastq());  // MergeQV
+    CheckInvalidTagLength("sq", Data::QualityValues("@@").Fastq());  // SubstitutionQV
+    CheckInvalidTagLength("dt", std::string("AA"));                  // DeletionTag
+    CheckInvalidTagLength("st", std::string("AA"));                  // SubstitutionTag
 
-    const Frames f{{42, 42, 42}};
+    const Data::Frames f{{42, 42, 42}};
     const auto& frames = f.Data();
     CheckInvalidTagLength("ip", frames);  // IPD
 
